@@ -7,20 +7,20 @@
 #' See the reference for detailed usage of \code{pdftk}.
 #' @param rotatepages a vector of page numbers to be rotated
 #' @param page_rotation An integer value from the vector c(0, 90, 180, 270).
-#' Each option sets the page rotation as follows (in degrees):
-#' north: 0, east: 90, south: 180, west: 270
-#' @param input_filepath the path of the input PDF file.
-#' The default is set to NULL. IF NULL, it  prompt the user to
-#' select the folder interactively.
-#' @param output_filepath the path of the output output PDF file.
-#' The default is set to NULL. IF NULL, it  prompt the user to
-#' select the folder interactivelye.
+#' Each option sets the page orientation as follows:
+#' north: 0, east: 90, south: 180, west: 270. Note that the orientation cannot be
+#' cummulatively changed (eg. 90 (east) will always turn the page so the beginning
+#' of the page is on the right side)
+#' @inheritParams input_filepath
+#' @inheritParams output_filepath
+#' @inheritParams overwrite
+#'
 #' @return this function returns a PDF document with the
 #' remaining pages
 #' @author Priyanga Dilini Talagala
 #' @examples
 #' \dontrun{
-#' # This command promts the user to select the file interactively.
+#' # This command prompts the user to select the file interactively.
 #' # Rotate page 2 and 6 to 90 degrees clockwise
 #' rotate_pages(rotatepages = c(3,6), page_rotation = 90)
 #' }
@@ -43,7 +43,7 @@
 #' @import utils
 #' @importFrom  stringr str_extract
 #' @references \url{https://www.pdflabs.com/tools/pdftk-the-pdf-toolkit/}
-rotate_pages <- function(rotatepages, page_rotation = c(0,90,180,270), input_filepath = NULL, output_filepath = NULL) {
+rotate_pages <- function(rotatepages, page_rotation = c(0,90,180,270), input_filepath = NULL, output_filepath = NULL, overwrite = TRUE) {
 
   assertthat::assert_that(is.numeric(rotatepages))
   page_rotation <- match.arg(as.character(page_rotation), c(0, 90, 180, 270))
@@ -53,6 +53,13 @@ rotate_pages <- function(rotatepages, page_rotation = c(0,90,180,270), input_fil
     #Choose the pdf file interactively
     input_filepath <- file.choose(new = FALSE)
   }
+  if(is.null(output_filepath)){
+    #Choose output file interactively
+    output_filepath <-  tcltk::tclvalue(tcltk::tkgetSaveFile(filetypes = '{Pdf {.pdf}}'))
+  }
+
+  input_filepath <- normalizePath(input_filepath, mustWork = TRUE)
+  output_filepath <- normalizePath(output_filepath, mustWork = FALSE)
 
   metadataTemp <- tempfile()
 
@@ -70,34 +77,40 @@ rotate_pages <- function(rotatepages, page_rotation = c(0,90,180,270), input_fil
 
   total <- 1:page_length
 
-  keep <- total[-rotatepages]
-  degree_0 <- split(keep, cumsum(seq_along(keep) %in% (which(diff(keep)>1)+1)))
-  index_0 <- as.vector(sapply(degree_0, function(x) x[[1]]))
-  f<-function(x){paste(min(x),"-",max(x),sep = "")}
-  degree_0 <-  as.vector(unlist(lapply(degree_0,f)))
+  # if all pages are being turned, just call rotate_pdf
+  # this is inefficient. fix later.
+  if(all(total %in% rotatepages )){
+    rotate_pdf(page_rotation = page_rotation,
+               input_filepath = input_filepath,
+               output_filepath = output_filepath,
+               overwrite = overwrite)
+  } else{
+    keep <- total[-rotatepages]
+    degree_0 <- split(keep, cumsum(seq_along(keep) %in% (which(diff(keep)>1)+1)))
+    index_0 <- as.vector(sapply(degree_0, function(x) x[[1]]))
+    f<-function(x){paste(min(x),"-",max(x),sep = "")}
+    degree_0 <-  as.vector(unlist(lapply(degree_0,f)))
 
 
-  direction <- c("north", "east", "south", "west" )[match(page_rotation,c(0,90,180,270))]
-  degree_x <- paste(rotatepages, direction, sep="")
+    direction <- c("north", "east", "south", "west" )[match(page_rotation,c(0,90,180,270))]
+    degree_x <- paste(rotatepages, direction, sep="")
 
-  index <- c(index_0,rotatepages)
-  rotate <-vector(class(degree_0), length(c(degree_0,degree_x)))
-  rotate[index[order(index)] %in% rotatepages] <- degree_x
-  rotate[!(index[order(index)] %in% rotatepages)] <- degree_0
+    index <- c(index_0,rotatepages)
+    rotate <-vector(class(degree_0), length(c(degree_0,degree_x)))
+    rotate[index[order(index)] %in% rotatepages] <- degree_x
+    rotate[!(index[order(index)] %in% rotatepages)] <- degree_0
 
-  if(is.null(output_filepath)){
-    #Choose output file interactively
-    output_filepath <-  tcltk::tclvalue(tcltk::tkgetSaveFile(filetypes = '{Pdf {.pdf}}'))
+    # Construct a system command to pdftk
+    system_command <- paste("pdftk", shQuote(input_filepath),
+                            "cat",
+                            paste(rotate,collapse=' '),
+                            "output",
+                            "{shQuote(output_filepath)}",
+                            sep = " ")
+
+    fileIO(input_filepath = input_filepath,
+           output_filepath = output_filepath,
+           overwrite = overwrite,
+           system_command = system_command)
   }
-
-  # Construct a system command to pdftk
-  system_command <- paste("pdftk",
-                          shQuote(input_filepath),
-                          "cat",
-                          paste(rotate,collapse=" "),
-                          "output",
-                          shQuote(output_filepath),
-                          sep = " ")
-  # Invoke the command
-  system(command = system_command)
 }
