@@ -5,19 +5,18 @@
 #'
 #' See the reference for detailed usage of \code{pdftk}.
 #' @param page_rotation An integer value from the vector c(0, 90, 180, 270).
-#' Each option sets the page rotation as follows (in degrees):
-#' north: 0, east: 90, south: 180, west: 270
-#' @param input_filepath the path of the input PDF file.
-#' The default is set to NULL. IF NULL, it  prompt the user to
-#' select the folder interactively.
-#' @param output_filepath the path of the output output PDF file.
-#' The default is set to NULL. IF NULL, it  prompt the user to
-#' select the folder interactivelye.
+#' Each option sets the page orientation as follows:
+#' north: 0, east: 90, south: 180, west: 270. Note that the orientation cannot be
+#' cummulatively changed (eg. 90 (east) will always turn the page so the beginning
+#' of the page is on the right side)
+#' @inheritParams input_filepath
+#' @inheritParams output_filepath
+#' @inheritParams overwrite
 #' @return this function returns a PDF document with the rotated pages
 #' @author Priyanga Dilini Talagala
 #' @examples
 #' \dontrun{
-#' # This command promts the user to select the file interactively.
+#' # This command prompts the user to select the file interactively.
 #' # Rotate the entire PDF document to 90 degrees clockwise
 #' rotate_pdf(page_rotation = 90)
 #' }
@@ -38,7 +37,7 @@
 #' }
 #' @export
 #' @references \url{https://www.pdflabs.com/tools/pdftk-the-pdf-toolkit/}
-rotate_pdf <- function(page_rotation = c(0, 90, 180, 270),  input_filepath = NULL, output_filepath = NULL) {
+rotate_pdf <- function(page_rotation = c(0, 90, 180, 270),  input_filepath = NULL, output_filepath = NULL, overwrite = TRUE) {
 
   page_rotation <- match.arg(as.character(page_rotation),c(0, 90, 180, 270))
 
@@ -53,6 +52,9 @@ rotate_pdf <- function(page_rotation = c(0, 90, 180, 270),  input_filepath = NUL
     output_filepath <-  tcltk::tclvalue(tcltk::tkgetSaveFile(filetypes = '{Pdf {.pdf}}'))
   }
 
+  input_filepath <- normalizePath(input_filepath, mustWork = TRUE)
+  output_filepath <- normalizePath(output_filepath, mustWork = FALSE)
+
   rotation <- c("1-endnorth", "1-endeast", "1-endsouth", "1-endwest" )[match(page_rotation,c(0,90,180,270))]
 
   # Construct a system command to pdftk
@@ -61,9 +63,12 @@ rotate_pdf <- function(page_rotation = c(0, 90, 180, 270),  input_filepath = NUL
                           "cat",
                           rotation,
                           "output",
-                          shQuote(output_filepath),
+                          "{shQuote(output_filepath)}",
                           sep = " ")
   # Invoke the command
-  system(command = system_command)
+  fileIO(input_filepath = input_filepath,
+         output_filepath = output_filepath,
+         overwrite = overwrite,
+         system_command = system_command)
 
 }
