@@ -5,9 +5,7 @@
 #' into individual pages.
 #'
 #' See the reference for detailed usage of \code{pdftk}.
-#' @param input_filepath the path of the input PDF file.
-#' The default is set to NULL. IF NULL, it  prompt the user to
-#' select the folder interactively.
+#' @inheritParams input_filepath
 #' @param output_directory the path of the output directory
 #' @param prefix A string for output filename prefix
 #' @return this function splits a single input PDF document into
@@ -44,6 +42,9 @@ split_pdf <- function(input_filepath = NULL, output_directory = NULL, prefix = '
     output_directory<- tcltk::tk_choose.dir(caption = "Select directory to save output")
   }
 
+  input_filepath <- normalizePath(input_filepath, mustWork = TRUE)
+  output_directory <- normalizePath(output_directory, mustWork =  TRUE)
+
   # Getting the page count to add the correct amout of zeroes to make it scalable
   metadataTemp <- tempfile()
   # Construct a system command to pdftk to get number of pages
@@ -60,7 +61,6 @@ split_pdf <- function(input_filepath = NULL, output_directory = NULL, prefix = '
 
   # Take the filepath arguments and format them for use in a system command
   output_filepath <- shQuote(paste0(output_directory, "/", prefix, "%0",digits,"d.pdf"))
-
   # Construct a system command to pdftk
   system_command <- paste("pdftk",
                           shQuote(input_filepath),
