@@ -8,9 +8,8 @@
 #' The default is set to NULL. If NULL, it  prompt the user to
 #' select the folder interactively.
 #' @param input_files a vector of input PDF files. The default is set to NULL. If NULL and \code{input_directory} is also NULL, the user is propted to select a folder interactively.
-#' @param output_filepath the path of the output output PDF file.
-#' The default is set to NULL. IF NULL, it  prompt the user to
-#' select the folder interactively.
+#' @inheritParams output_filepath
+#' @inheritParams overwrite
 #' @return this function returns a combined PDF document
 #' @author Priyanga Dilini Talagala and Daniel Padfield
 #' @examples
@@ -27,13 +26,13 @@
 #' dev.off()
 #' }
 #' output_file <- file.path(dir, paste('Full_pdf.pdf',  sep = ""))
-#' staple_pdf(input_directory = dir, output_file)
+#' staple_pdf(input_directory = dir, output_filepath = output_file)
 #' }
 #' @export
 #' @importFrom tcltk tk_choose.dir
 #' @references \url{https://www.pdflabs.com/tools/pdftk-the-pdf-toolkit/}
 staple_pdf <- function(input_directory = NULL, input_files = NULL,
-                       output_filepath = NULL)
+                       output_filepath = NULL, overwrite = TRUE)
 {
   # set error if neither input_directory of input_files are null
   if(!is.null(input_directory) & !is.null(input_files)){
@@ -51,6 +50,13 @@ staple_pdf <- function(input_directory = NULL, input_files = NULL,
     output_filepath <-  tcltk::tclvalue(tcltk::tkgetSaveFile(filetypes = '{Pdf {.pdf}}'))
   }
 
+  input_filepaths <- normalizePath(input_filepaths, mustWork = TRUE)
+  output_filepath <- normalizePath(output_filepath, mustWork = FALSE)
+
+  if(!overwrite & file.exists(output_filepath)){
+    stop(paste(output_filepath,'already exists. Set overwrite = TRUE to overwrite'))
+  }
+
   # Construct a system command to pdftk
   system_command <- paste("pdftk",
                           paste(shQuote(input_filepaths), collapse = " "),
